@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use Scalar::Util qw( blessed refaddr weaken );
 
@@ -376,6 +376,76 @@ sub _strip_options {
     }
 }
 
+# -----------------------------------------------
+
+sub format_node
+{
+	my($self, $options, $node) = @_;
+	my($s) = $node -> value;
+	$s     .= '. Attributes: ' . $self -> hashref2string($node -> meta) if (! $$options{no_attributes});
+
+	return $s;
+
+} # End of format_node.
+
+# -----------------------------------------------
+
+sub hashref2string
+{
+	my($self, $hashref) = @_;
+	$hashref ||= {};
+
+	return '{' . join(', ', map{qq|$_ => "$$hashref{$_}"|} sort keys %$hashref) . '}';
+
+} # End of hashref2string.
+
+# -----------------------------------------------
+
+sub node2string
+{
+	my($self, $options, $node, $vert_dashes) = @_;
+	my($depth)         = $node -> depth;
+	my(@siblings)      = $node -> parent -> children;
+	my($sibling_count) = scalar @siblings; # Warning: Don't combine this with the previous line.
+	my($offset)        = ' ' x 4;
+	my(@indent)        = map{$$vert_dashes[$_] || $offset} 0 .. $depth - 1;
+	@$vert_dashes      =
+	(
+		@indent,
+		($sibling_count == 0 ? $offset : '    |'),
+	);
+
+	my(@i)                = $node -> parent -> get_index_for($node);
+	my(@indexes)          = $node -> parent -> get_index_for($node);
+	$$vert_dashes[$depth] = ($offset . ' ') if ($sibling_count == ($indexes[0] + 1) );
+
+	return join('', @indent[1 .. $#indent]) . ($depth ? '    |--- ' : '') . $self -> format_node($options, $node);
+
+} # End of node2string.
+
+# ------------------------------------------------
+
+sub tree2string
+{
+	my($self, $options)      = @_;
+	$options                 ||= {};
+	$$options{no_attributes} ||= 0;
+	my(@nodes)               = $self -> traverse;
+
+	my(@out);
+	my(@vert_dashes);
+
+	for my $i (0 .. $#nodes)
+	{
+		push @out, $self -> node2string($options, $nodes[$i], \@vert_dashes);
+	}
+
+	return [@out];
+
+} # End of tree2string.
+
+# -----------------------------------------------
+
 1;
 __END__
 
@@ -494,8 +564,8 @@ remove_child() resets last_error() upon entry.
 This will modify the tree such that it is a mirror of what it was before. This
 means that the order of all children is reversed.
 
-B<NOTE>: This is a destructive action. It I<will> modify the tree's internal
-structure. If you wish to get a mirror, yet keep the original tree intact, use
+B<NOTE>: This is a destructive action. It I<will> modify the internal structure
+of the tree. If you wish to get a mirror, yet keep the original tree intact, use
 C<< my $mirror = $tree->clone->mirror >>.
 
 mirror() does not reset last_error() because it (mirror() ) is implemented in L<Tree::Fast>,
@@ -537,6 +607,62 @@ Use C<< $tree->LEVEL_ORDER >> as the C<$order>.
 traverse() does not reset last_error() because it (traverse() ) is implemented in L<Tree::Fast>,
 which has no error handling.
 
+=head2 tree2string($options)
+
+Returns an arrayref of lines, suitable for printing. These lines do not end in "\n".
+
+Draws a nice ASCII-art representation of the tree structure.
+
+The tree looks like:
+
+Root. Attributes: {uid => "0"}
+    |--- H. Attributes: {uid => "1"}
+    |    |--- I. Attributes: {uid => "2"}
+    |    |    |--- J. Attributes: {uid => "3"}
+    |    |--- K. Attributes: {uid => "4"}
+    |    |--- L. Attributes: {uid => "5"}
+    |--- M. Attributes: {uid => "6"}
+    |--- N. Attributes: {uid => "7"}
+         |--- O. Attributes: {uid => "8"}
+              |--- P. Attributes: {uid => "9"}
+                   |--- Q. Attributes: {uid => "10"}
+
+Or, without attributes:
+
+Root
+    |--- H
+    |    |--- I
+    |    |    |--- J
+    |    |--- K
+    |    |--- L
+    |--- M
+    |--- N
+         |--- O
+              |--- P
+                   |--- Q
+
+See scripts/print.tree.pl.
+
+Example usage:
+
+  print map("$_\n", @{$tree -> tree2string});
+
+If you do not wish to supply options, use C<tree2string()> or C<tree2string({})>.
+
+Possible keys in the $options hashref (which defaults to {}):
+
+=over 4
+
+=item o no_attributes => $Boolean
+
+If 1, the node attributes are not included in the string returned.
+
+Default: 0 (include attributes).
+
+=back
+
+Calls L</node2string($options, $node, $vert_dashes)>.
+
 =head2 State Queries
 
 =head2 is_root()
@@ -598,7 +724,7 @@ a width equal to the sum of all the widths of its children.
 This will return the depth of C<$tree>. A root has a depth of 0. A child has
 the depth of its parent, plus 1.
 
-This is the distance from the root. It's useful for things like
+This is the distance from the root. It is useful for things like
 pretty-printing the tree.
 
 =head2 size()
@@ -630,6 +756,58 @@ top-level metadata hashref, keyed by your package name. L<Tree::Persist> does
 this, using a unique key for each persistence layer associated with that tree.
 This will help prevent clobbering of metadata.
 
+=head2 format_node($options, $node)
+
+Returns a string consisting of the node's name and, optionally, it's attributes.
+
+Possible keys in the $options hashref:
+
+=over 4
+
+=item o no_attributes => $Boolean
+
+If 1, the node attributes are not included in the string returned.
+
+Default: 0 (include attributes).
+
+=back
+
+Calls L</hashref2string($hashref)>.
+
+Called by L</node2string($options, $node, $vert_dashes)>.
+
+You would not normally call this method.
+
+If you do not wish to supply options, use format_node({}, $node).
+
+=head2 hashref2string($hashref)
+
+Returns the given hashref as a string.
+
+Called by L</format_node($options, $node)>.
+
+=head2 node2string($options, $node, $vert_dashes)
+
+Returns a string of the node name and attributes, with a leading indent, suitable for printing.
+
+Possible keys in the $options hashref:
+
+=over 4
+
+=item o no_attributes => $Boolean
+
+If 1, the node attributes are not included in the string returned.
+
+Default: 0 (include attributes).
+
+=back
+
+Ignore the parameter $vert_dashes. The code uses it as temporary storage.
+
+Calls L</format_node($options, $node)>.
+
+Called by L</tree2string($options)>.
+
 =head1 ERROR HANDLING
 
 Describe what the default error handlers do and what a custom error handler is
@@ -749,7 +927,7 @@ The Tree::Null object is a singleton.
 
 =item *
 
-The Tree::Null object I<is> defined, though. I couldn't find a way to
+The Tree::Null object I<is> defined, though. I could not find a way to
 make it evaluate as undefined. That may be a good thing.
 
 =back
@@ -767,9 +945,9 @@ L<Tree::DAG_Node>. More details: L</SEE ALSO>.
 =head2 How do I implement the visitor pattern?
 
 I have deliberately chosen to not implement the Visitor pattern as described
-by Gamma et al. Given a sufficiently powerful C<traverse()> and Perl's
-capabilities, an explicit visitor object is almost always unneeded. If you
-want one, it's easy to write one yourself. Here's a simple one I wrote in 5
+by Gamma et al. Given a sufficiently powerful C<traverse()> and the capabilities
+of Perl, an explicit visitor object is almost always unneeded. If you
+want one, it is easy to write one yourself. Here is a simple one I wrote in 5
 minutes:
 
   package My::Visitor;
@@ -795,7 +973,7 @@ minutes:
 
 =head2 Should I implement the visitor pattern?
 
-No. You're better off using the L<Tree::DAG_Node/walk_down($options)> method.
+No. You are better off using the L<Tree::DAG_Node/walk_down($options)> method.
 
 =head1 SEE ALSO
 
